@@ -1,6 +1,7 @@
 import calendar
 import datetime
 import os
+import time
 from datetime import timedelta
 
 from notedata.tables import SqliteTable
@@ -31,15 +32,19 @@ class AutoSaveDetail(SqliteTable):
         time_unix = datetime.datetime.now()
         if self.save_freq in ('d', 'D', 'Day', 'day'):
             if self.save_time_unix.day != time_unix.day:
-                self._save(now=self.save_time_unix)
+                self._save(now=self.save_time_unix, pop=self.save_with_clear)
+                self.save_time_unix = time_unix
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
             if self.save_time_unix.month != time_unix.month:
-                self._save(now=self.save_time_unix)
+                self._save(now=self.save_time_unix, pop=self.save_with_clear)
+                self.save_time_unix = time_unix
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
             if self.save_time_unix.year != time_unix.year:
-                self._save(now=self.save_time_unix)
+                self._save(now=self.save_time_unix, pop=self.save_with_clear)
+                self.save_time_unix = time_unix
 
     def _save(self, pop=None, now=None):
+        now = now or datetime.datetime.now()
         path_root = os.path.join(os.path.dirname(self.db_path), self.table_name)
         if not os.path.exists(path_root):
             os.makedirs(path_root)
@@ -63,13 +68,12 @@ class AutoSaveDetail(SqliteTable):
             condition2 = None
 
         path = '{}/{}-{}.csv'.format(path_root, name, self.save_time_unix.strftime(fmt))
+        print(condition)
 
         self.to_csv(condition=condition, path=path)
-        if pop or self.save_with_clear:
+        if pop:
             self.delete(condition2)
 
-        self.save_time_unix = now
-
     def between_unix_ms(self, now):
         now = now or datetime.datetime.now()
 
@@ -81,6 +85,16 @@ class AutoSaveDetail(SqliteTable):
         this_month_end = this_month_start + timedelta(days=calendar.monthrange(now.year, now.month)[1])
         this_year_start = datetime.datetime(now.year, 1, 1).date()
         this_year_end = datetime.datetime(now.year + 1, 1, 1).date()
+
+        this_day_start = self.date2unix(this_day_start.timetuple())
+        this_day_end = self.date2unix(this_day_end.timetuple()) - 1
+        this_week_start = self.date2unix(this_week_start.timetuple())
+        this_week_end = self.date2unix(this_week_end.timetuple()) - 1
+        this_month_start = self.date2unix(this_month_start.timetuple())
+        this_month_end = self.date2unix(this_month_end.timetuple()) - 1
+        this_year_start = self.date2unix(this_year_start.timetuple())
+        this_year_end = self.date2unix(this_year_end.timetuple()) - 1
+
         if self.save_freq in ('d', 'D', 'Day', 'day'):
             return this_day_start, this_day_end
         elif self.save_freq in ('m', 'M', 'mon', 'Mon', 'month', 'Month'):
@@ -92,6 +106,12 @@ class AutoSaveDetail(SqliteTable):
         else:
             return this_day_start, this_day_end
 
+    @staticmethod
+    def date2unix(t, ms=True):
+        if ms:
+            return time.mktime(t) * 1000
+        return time.mktime(t)
+
 
 class TradeDetail(AutoSaveDetail):
     def __init__(self, table_name='trade_detail', db_path=None, *args, **kwargs):
