@@ -97,16 +97,16 @@ class TradeUpdate:
         self.kline_1year.auto_save()
 
     def _save(self):
-        self.tradeDB._save()
-        self.kline_1min._save()
-        self.kline_5min._save()
-        self.kline_15min._save()
-        self.kline_30min._save()
-        self.kline_4hour._save()
-        self.kline_1day._save()
-        self.kline_1mon._save()
-        self.kline_1week._save()
-        self.kline_1year._save()
+        self.tradeDB._save(pop=False)
+        self.kline_1min._save(pop=False)
+        self.kline_5min._save(pop=False)
+        self.kline_15min._save(pop=False)
+        self.kline_30min._save(pop=False)
+        self.kline_4hour._save(pop=False)
+        self.kline_1day._save(pop=False)
+        self.kline_1mon._save(pop=False)
+        self.kline_1week._save(pop=False)
+        self.kline_1year._save(pop=False)
 
     def insert_data(self, trade=True, kline=True):
         symbols = self.symbolDB.select("select symbol from {} where state ='online'".format(self.symbolDB.table_name))
@@ -153,4 +153,6 @@ class TradeUpdate:
 update = TradeUpdate()
 update.run()
 
+# ps -elf|grep coin
 # nohup /root/anaconda3/bin/python3.8 /root/workspace/notechats/notecoin/notecoin/huobi/dataset/update.py >>/root/workspace/tmp/notecoin-run-$(date +%Y-%m-%d).log 2>&1 &
+# 2509
